@@ -135,7 +135,7 @@ def delete_message(receipt_handle):
 def process_messages_queue():
     messages = read_queue_messages()
 
-    for msg in messages["Messages"]:
+    for msg in messages.get("Messages", []):
         try:
             msg_body = json.loads(msg["Body"])
         except json.decoder.JSONDecodeError as e:
